eval 'exec perl -w -S $0 ${1+"$@"}'
    if 0;

################################################################################
#
# $RCSfile: iowremote_amarok.pl $
#
#
# This program is Copyright (C) 02/2006 Matthias Prinke
# <matthias.prinke@surfeu.de> and covered by GNU's GPL.
# In particular, this program is free software and comes WITHOUT
# ANY WARRANTY.
#
# $Author: mp $
#
# $Date: 2006/02/26 $
#
# $Revision: 0.0.1 $
#
################################################################################

package iowremote_amarok;

use strict;
use warnings;
use DCOP::Amarok::Player;
use IO::Socket;
use IO::Select;

our $VERSION = '0.0.1';

#### BEGIN CONFIG
# Configuration Options
## iowlircemu
my $user      = "$ENV{USER}";
my $remote_id = "amarok";
### END CONFIG

=head1 NAME

iowremote_amarok

=head1 DESCRIPTION

This program receives infrared remote control
commands via a UNIX domain socket from iowlircemu
and sends them via DCOP to amaroK.

=cut

my $amarok  = DCOP::Amarok::Player->new( user => "$user" ) or die "Could'nt attach to DCOP: $!\n";
my $status  = ( $amarok->status() > 0 ) ? 1 : 0;
my $readset = new IO::Select();
my $verbose = 0;

# create unix socket connection to iowlircemu
socket(CLIENT, PF_UNIX, SOCK_STREAM, 0);
connect(CLIENT, sockaddr_un("/dev/lircd"))
  or die "iowremote_amarok: Can't connect to /dev/lircd: $!";


# catch TERM signal
$SIG{TERM} = \&bye;

$readset->add(\*CLIENT, \*STDIN);

# receive some status info via STDIN from amaroK or a remote control command
while(1) {
  if (my @ready = $readset->can_read) {  
    foreach my $handle (@ready) {
      if ($handle == \*CLIENT) {
	$_ = <CLIENT>;
	print $_ if $verbose;
        if (/$remote_id/) {
	  if (/toggleRandom/) {
            print "\niowremote_amarok: toggleRandom\n" if $verbose;
	    $amarok->toggleRandom();
	    # The remote control sends the command repeatedly,
	    # trying to ignore the following transmissions.
	    sleep 1;
	    $handle->flush();
	  } elsif (/playPause/) {
            print "\niowremote_amarok: playPause\n" if $verbose;
	    $amarok->playPause();
	    sleep 1;
	    $handle->flush();
	  } elsif (/stop/) {
            print "\niowremote_amarok: stop\n" if $verbose;
	    $amarok->stop();
	    sleep 1;
	    $handle->flush();
	  } elsif (/prev/) {
            print "\niowremote_amarok: prev\n" if $verbose;
	    $amarok->prev();
	    sleep 1;
	    $handle->flush();
	  } elsif (/next/) {
            print "\niowremote_amarok: next\n" if $verbose;
	    $amarok->next();
	    sleep 1;
	    $handle->flush();
	  } elsif (/rew/) {
            print "\niowremote_amarok: rew\n" if $verbose;
	    $amarok->rew();
	  } elsif (/fwd/) {
	    $amarok->fwd();
            print "\niowremote_amarok: fwd\n" if $verbose;
	  } elsif (/volumeUp/) {
            print "\niowremote_amarok: volumeUp\n" if $verbose;
	    $amarok->volUp();
	  } elsif (/volumeDown/) {
            print "\niowremote_amarok: volumeDown\n" if $verbose;
	    $amarok->volDn();
	  } elsif (/mute/) {
            print "\niowremote_amarok: mute\n" if $verbose;
	    $amarok->mute();
	    sleep 1;
	    $handle->flush();
	  }
	} # if (/$remote_id/) {
      } elsif ($handle == \*STDIN) {
        $_ = <STDIN>;
      
        if (/configure/) {
	  print "\niowremote_amarok: configure\n" if $verbose;

	} elsif ( /trackChange/ ) {
          printf("\n%s-%s\n", $amarok->artist(), $amarok->title())if $verbose
	} elsif ( /engineStateChange/ ) {
	  if( /playing/ ) {
	    $status = 1;
	    printf("\niowremote_amarok: Playing %s\n",$amarok->title()) if $verbose;
	  } elsif ( /pause/ ) {
	    $status = 1;
	    print "\niowlcd_amarok: pause\n" if $verbose;
	  } else {
	    $status = 0;
	    print "\niowlcd_amarok: stopped\n" if $verbose;
	  }
	} elsif ( /volumeChange/ ){

	}
	exit if(/exit/); #for debugging
	&bye() if(/kill/); # first kill, then exit... after thread has exited
      } # elsif ($handle == STDIN)
    } # foreach my $handle (@ready)
  } # if (my @ready = $readset->can_read)
} # while (1)


# end program
sub bye {
  sleep 1;

  # create unix socket connection to iowlircemu
  close(CLIENT);
  exit 0;
}

__END__

=head1 AUTHOR

M. Prinke E<lt>matthias.prinke@surfeu.deE<gt>

=head1 COPYRIGHT (COPYLEFT)

2006, M. Prinke

=head1 LICENSE

This programs is licensed under the terms of the GPL. 

=cut
